from pygame import mixer
import audioread
import time
from typing import List


class TocarAudios(object):
    def __init__(self, paths_abs: List[str]) -> None:
        self.paths_ans = paths_abs
        # Iniciando o mixer
        mixer.init()

    def ouvir_lista(self) -> None:
        atual = 1
        print()
        for i in self.paths_ans:
            print(f"Qt. Áudio: {len(self.paths_ans)} | Qt. Escutado: {atual}")
            atual += 1
            self.tocar(i)
            # infinite loop
            tempo = self.__get_audio_duration(i)
            end_time = time.time() + tempo
            while time.time() <= end_time:
                continue    # futura atualização
                print("Precione 'p' para [Pausar], 'r' para reiniciar.")
                print("Precione 'e' para [Sair].")
                query = input("  ")
                if query == 'p':
                    # Pausing the music
                    mixer.music.pause()
                elif query == 'r':
                    # Resuming the music
                    mixer.music.unpause()
                elif query == 'e':
                    # Stop the mixer
                    mixer.music.stop()
                    break

    def tocar(self, audio: str) -> None:
        # Carregando audio
        mixer.music.load(audio)
        # Configurando volume
        mixer.music.set_volume(0.7)
        # Tocar áudio
        mixer.music.play()

    @staticmethod
    def __get_audio_duration(audio: str) -> float:
        with audioread.audio_open(audio) as f:
            # total de tempo em segundo do arquivo de audio
            totalsec = f.duration
        return totalsec



#!/usr/bin/env /home/bits/CursoIngles/Curso_de_Ingles_vm5_2022/programas_auxiliares/audIG/.venv/bin/python3.10
from audig import Caminhos
from audig import TocarAudios


class Run:
    def __init__(self):
        pass
        # self.run()

    def run(self) -> None:
        # Diretório raiz do curso.
        path = "/home/bits/CursoIngles/Curso_de_Ingles_vm5_2022/01_Fundacao"
        # Subdiretórios a serem listado os áudios
        sub_dirs = ["Módulo 02", ]
        # Instanciando um objeto Caminhos
        caminhos = Caminhos(path=path, subdirs=sub_dirs)
        # obtendo os caminhos absolutos dos arquivos de áudios.
        paths_abs = caminhos.get_paths()

        toca_audios = TocarAudios(paths_abs=paths_abs)
        toca_audios.ouvir_lista()


if __name__ == "__main__":
    Run().run()



import os
from os.path import isfile
from collections.abc import Iterable
from typing import List
import re


class Caminhos(object):
    def __init__(self, path: str, subdirs: Iterable[str]) -> None:
        self.path = path
        self.subdirs = subdirs
        self.__entrar_dir()
        self.verificar = re.compile(r"Comple")
        self.complete_path: List[str] = []

    def __entrar_dir(self) -> None:
        os.chdir(self.path)

    def __entrar_subdir(self) -> None:
        for subdir in self.subdirs:
            os.chdir(subdir)
            for i in sorted(os.listdir()):
                if not isfile(i) and not self.verificar.search(i):
                    self.list_file_mp3(i)
            self.__sair_subdir()

    @staticmethod
    def __sair_subdir() -> None:
        os.chdir("..")

    def list_file_mp3(self, subdir: str) -> None:
        # Entra no subdiretório da Aula xx
        os.chdir(subdir)

        # lista todas as pastas e arquivos do diretório
        for i in sorted(os.listdir()):
            # filtra apenas os arquivos .mp3 para adicionar
            # a lista de reprodução
            if i[-4:] == ".mp3":
                # obtem o caminho completo do arquivo .mp3
                path_abs = os.getcwd() + "/" + i

                # Adiciona o caminho absoluto obtido a lista de reprodução
                self.complete_path.append(path_abs)
        self.__sair_subdir()

    def get_paths(self) -> List[str]:
        self.__entrar_subdir()
        self.__sair_subdir()
        return self.complete_path


if __name__ == "__main__":
    path = "/home/bits/CursoIngles/Curso_de_Ingles_vm5_2022/01_Fundacao"
    sub_dirs = ["Módulo 02", ]
    caminhos = Caminhos(path=path, subdirs=sub_dirs)
    paths_abs = caminhos.get_paths()
